Type hint extraction from Python AST
This module extracts type annotations from Python code and converts them to Spydecy’s type system.
Functions
- extract_
type_ hints - Extract type hints from Python AST
Type hint extraction from Python AST
This module extracts type annotations from Python code and converts them to Spydecy’s type system.